### Name: rmh.default
### Title: Simulate Point Process Models using the Metropolis-Hastings
###   Algorithm.
### Aliases: rmh.default
### Keywords: spatial

### ** Examples

   ##Don't run: library(spatstat)
   ##Don't run: 
##D     # Strauss process.
##D     mod01 <- list(cif="strauss",par=c(beta=2,gamma=0.2,r=0.7),
##D                   w=c(0,10,0,10))
##D     X1.strauss <- rmh(model=mod01,start=list(n.start=80),
##D                       control=list(nrep=1e5,nverb=5000))
##D 
##D     # Strauss process, conditioning on n = 80:
##D     X2.strauss <- rmh(model=mod01,start=list(n.start=80),
##D                       control=list(p=1,nrep=1e5,nverb=5000))
##D     
##D     x     <- c(0.55,0.68,0.75,0.58,0.39,0.37,0.19,0.26,0.42)
##D     y     <- c(0.20,0.27,0.68,0.99,0.80,0.61,0.45,0.28,0.33)
##D     mod02 <- list(cif="strauss",par=c(beta=2000,gamma=0.6,r=0.7),
##D                  w=owin(poly=list(x=x,y=y)))
##D     X3.strauss <- rmh(model=mod02,start=list(n.start=90),
##D                       control=list(nrep=1e5,nverb=5000))
##D 
##D     # Strauss process equal to pure hardcore:
##D     mod03 <- list(cif="strauss",par=c(beta=2,gamma=0,r=0.7),w=c(0,10,0,10))
##D     X4.strauss <- rmh(model=mod03,start=list(n.start=60),
##D                       control=list(nrep=1e5,nverb=5000,iseed=c(42,17,69)))
##D 
##D     # Another Strauss process, starting off from X3.strauss (but
##D     # with a rectangular window):
##D     xxx <- X3.strauss
##D     xxx$w <- as.owin(c(0,1,0,1))
##D     X3.strauss <- rmh(model=mod02,start=list(x.start=xxx),
##D                       control=list(nrep=1e5,nverb=5000))
##D     
##D     # Strauss with hardcore:
##D     mod04 <- list(cif="straush",par=c(beta=2,gamma=0.2,r=0.7,hc=0.3),
##D                  w=c(0,10,0,10))
##D     X1.straush <- rmh(model=mod04,start=list(n.start=70),
##D                       control=list(nrep=1e5,nverb=5000))
##D     
##D     # Another Strauss with hardcore (with a perhaps surprizing
##D     # result):
##D     mod05 <- list(cif="straush",par=c(beta=80,gamma=0.36,r=45,hc=2.5),
##D                  w=c(0,250,0,250))
##D     X2.straush <- rmh(model=mod05,start=list(n.start=250),
##D                       control=list(nrep=1e5,nverb=5000))
##D     
##D     # Pure hardcore (identical to X3.strauss).
##D     mod06 <- list(cif="straush",par=c(beta=2,gamma=1,r=1,hc=0.7),
##D                  w=c(0,10,0,10))
##D     X3.straush <- rmh(model=mod06,start=list(n.start=60),
##D                       control=list(nrep=1e5,nverb=5000,iseed=c(42,17,69)))
##D     
##D     # Soft core:
##D     par3 <- c(0.8,0.1,0.5)
##D     w    <- c(0,10,0,10)
##D     mod07 <- list(cif="sftcr",par=c(beta=0.8,sigma=0.1,kappa=0.5),
##D                  w=c(0,10,0,10))
##D     X.sftcr <- rmh(model=mod07,start=list(n.start=70),
##D                    control=list(nrep=1e5,nverb=5000))
##D     
##D     # Multitype Strauss:
##D     beta <- c(0.027,0.008)
##D     gmma <- matrix(c(0.43,0.98,0.98,0.36),2,2)
##D     r    <- matrix(c(45,45,45,45),2,2)
##D     mod08 <- list(cif="straussm",par=list(beta=beta,gamma=gmma,radii=r),
##D                  w=c(0,250,0,250))
##D     X1.straussm <- rmh(model=mod08,start=list(n.start=80),
##D                        control=list(ptypes=c(0.75,0.25),nrep=1e5,nverb=5000))
##D     
##D     # Multitype Strauss conditioning upon the total number
##D     # of points being 80:
##D     X2.straussm <- rmh(model=mod08,start=list(n.start=80),
##D                        control=list(p=1,ptypes=c(0.75,0.25),nrep=1e5,
##D                                     nverb=5000))
##D     
##D     # Conditioning upon the number of points of type 1 being 60
##D     # and the number of points of type 2 being 20:
##D     X3.straussm <- rmh(model=mod08,start=list(n.start=c(60,20)),
##D                        control=list(fixall=TRUE,p=1,ptypes=c(0.75,0.25),
##D                                     nrep=1e5,nverb=5000))
##D 
##D     # Multitype Strauss hardcore:
##D     rhc  <- matrix(c(9.1,5.0,5.0,2.5),2,2)
##D     mod09 <- list(cif="straushm",par=list(beta=beta,gamma=gmma,
##D                  iradii=r,hradii=rhc),w=c(0,250,0,250))
##D     X.straushm <- rmh(model=mod09,start=list(n.start=80),
##D                       control=list(ptypes=c(0.75,0.25),nrep=1e5,nverb=5000))
##D     
##D     # Multitype Strauss hardcore with trends for each type:
##D     beta  <- c(0.0027,0.08)
##D     tpar1 <- c(0.02,0.004,-0.0004,0.004,-0.0004) # Coefs. for log quadratic
##D     tpar2 <- c(-0.06,0.05)                       # and log linear trends.
##D     mod10 <- list(cif="straushm",par=list(beta=beta,gamma=gmma,
##D                   iradii=r,hradii=rhc),w=c(0,250,0,250),
##D                   tpar=list(tpar1,tpar2))
##D     X1.straushm.trend <- rmh(model=mod10,start=list(n.start=350),
##D                              control=list(ptypes=c(0.75,0.25),
##D                              nrep=1e5,nverb=5000))
##D     
##D     # Diggle, Gates, and Stibbard:
##D     mod11 <- list(cif="dgs",par=c(beta=3600,rho=0.08),w=c(0,1,0,1))
##D     X.dgs <- rmh(model=mod11,start=list(n.start=300),
##D                  control=list(nrep=1e5,nverb=5000))
##D     
##D     # Diggle-Gratton:
##D     mod12 <- list(cif="diggra",
##D                   par=c(beta=1800,kappa=3,delta=0.02,rho=0.04),
##D                   w=square(1))
##D     X.diggra <- rmh(model=mod12,start=list(n.start=300),
##D                     control=list(nrep=1e5,nverb=5000))
##D     
##D     # Geyer:
##D     mod13 <- list(cif="geyer",par=c(beta=1.25,gamma=1.6,r=0.2,sat=4.5),
##D                   w=c(0,10,0,10))
##D     X1.geyer <- rmh(model=mod13,start=list(n.start=200),
##D                     control=list(nrep=1e5,nverb=5000))
##D 
##D     # Geyer; same as a Strauss process with parameters
##D     # (beta=2.25,gamma=0.16,r=0.7):
##D 
##D     mod14 <- list(cif="geyer",par=c(beta=2.25,gamma=0.4,r=0.7,sat=10000),
##D                   w=c(0,10,0,10))
##D     X2.geyer <- rmh(model=mod14,start=list(n.start=200),
##D                     control=list(nrep=1e5,nverb=5000))
##D 
##D     mod15 <- list(cif="geyer",par=c(beta=8.1,gamma=2.2,r=0.08,sat=3))
##D     data(redwood)
##D     X3.geyer <- rmh(model=mod15,start=list(x.start=redwood),
##D                     control=list(periodic=TRUE,nrep=1e5,nverb=5000))
##D 
##D     # Geyer, starting from the redwood data set, simulating
##D     # on a torus, and conditioning on n:
##D     X4.geyer <- rmh(model=mod15,start=list(x.start=redwood),
##D                     control=list(p=1,periodic=TRUE,nrep=1e5,nverb=5000))
##D    
   
    # Strauss process.
    mod01 <- list(cif="strauss",par=c(beta=2,gamma=0.2,r=0.7),
                  w=c(0,10,0,10))
    X1.strauss <- rmh(model=mod01,start=list(n.start=80),
                      control=list(nrep=100,nverb=50))

    # Strauss process, conditioning on n = 80:
    X2.strauss <- rmh(model=mod01,start=list(n.start=80),
                      control=list(p=1,nrep=10,nverb=5))
    
    x     <- c(0.55,0.68,0.75,0.58,0.39,0.37,0.19,0.26,0.42)
    y     <- c(0.20,0.27,0.68,0.99,0.80,0.61,0.45,0.28,0.33)
    mod02 <- list(cif="strauss",par=c(beta=2000,gamma=0.6,r=0.7),
                 w=owin(poly=list(x=x,y=y)))
    X3.strauss <- rmh(model=mod02,start=list(n.start=90),
                      control=list(nrep=10,nverb=5))
    

    # Strauss process == pure hardcore:
    mod03 <- list(cif="strauss",par=c(beta=2,gamma=0,r=0.7),w=c(0,10,0,10))
    X4.strauss <- rmh(model=mod03,start=list(n.start=60),
                      control=list(nrep=10,nverb=5,iseed=c(42,17,69)))

    # Another Strauss process, starting off from X3.strauss (but
    # with a rectangular window):
    xxx <- X3.strauss
    xxx$w <- as.owin(c(0,1,0,1))
    X3.strauss <- rmh(model=mod02,start=list(x.start=xxx),
                      control=list(nrep=10,nverb=5))
    
    # Strauss with hardcore:
    mod04 <- list(cif="straush",par=c(beta=2,gamma=0.2,r=0.7,hc=0.3),
                 w=c(0,10,0,10))
    X1.straush <- rmh(model=mod04,start=list(n.start=70),
                      control=list(nrep=10,nverb=5))
    
    # Another Strauss with hardcore (with a perhaps surprizing
    # result):
    mod05 <- list(cif="straush",par=c(beta=80,gamma=0.36,r=45,hc=2.5),
                 w=c(0,250,0,250))
    X2.straush <- rmh(model=mod05,start=list(n.start=250),
                      control=list(nrep=10,nverb=5))
    
    # Pure hardcore (identical to X3.strauss).
    mod06 <- list(cif="straush",par=c(beta=2,gamma=1,r=1,hc=0.7),
                 w=c(0,10,0,10))
    X3.straush <- rmh(model=mod06,start=list(n.start=60),
                      control=list(nrep=10,nverb=5,iseed=c(42,17,69)))
    
    # Soft core:
    par3 <- c(0.8,0.1,0.5)
    w    <- c(0,10,0,10)
    mod07 <- list(cif="sftcr",par=c(beta=0.8,sigma=0.1,kappa=0.5),
                 w=c(0,10,0,10))
    X.sftcr <- rmh(model=mod07,start=list(n.start=70),
                   control=list(nrep=10,nverb=5))
    
    # Multitype Strauss:
    beta <- c(0.027,0.008)
    gmma <- matrix(c(0.43,0.98,0.98,0.36),2,2)
    r    <- matrix(c(45,45,45,45),2,2)
    mod08 <- list(cif="straussm",par=list(beta=beta,gamma=gmma,radii=r),
                 w=c(0,250,0,250))
    X1.straussm <- rmh(model=mod08,start=list(n.start=80),
                       control=list(ptypes=c(0.75,0.25),nrep=10,nverb=5))
    
    # Multitype Strauss conditioning upon the total number
    # of points being 80:
    X2.straussm <- rmh(model=mod08,start=list(n.start=80),
                       control=list(p=1,ptypes=c(0.75,0.25),
                                    nrep=10,nverb=5))
    
    # Conditioning upon the number of points of type 1 being 60
    # and the number of points of type 2 being 20:
    X3.straussm <- rmh(model=mod08,start=list(n.start=c(60,20)),
                       control=list(fixall=TRUE,p=1,ptypes=c(0.75,0.25),
                                    nrep=10,nverb=5))

    # Multitype Strauss hardcore:
    rhc  <- matrix(c(9.1,5.0,5.0,2.5),2,2)
    mod09 <- list(cif="straushm",par=list(beta=beta,gamma=gmma,
                 iradii=r,hradii=rhc),w=c(0,250,0,250))
    X.straushm <- rmh(model=mod09,start=list(n.start=80),
                      control=list(ptypes=c(0.75,0.25),nrep=10,nverb=5))
    
    # Multitype Strauss hardcore with trends for each type:
    beta  <- c(0.0027,0.08)
    tpar1 <- c(0.02,0.004,-0.0004,0.004,-0.0004) # Coefs. for log quadratic
    tpar2 <- c(-0.06,0.05)                       # and log linear trends.
    mod10 <- list(cif="straushm",par=list(beta=beta,gamma=gmma,
                  iradii=r,hradii=rhc),w=c(0,250,0,250),
                  tpar=list(tpar1,tpar2))
    X1.straushm.trend <- rmh(model=mod10,start=list(n.start=350),
                             control=list(ptypes=c(0.75,0.25),
                             nrep=10,nverb=5))
    
    # Diggle, Gates, and Stibbard:
    mod11 <- list(cif="dgs",par=c(beta=3600,rho=0.08),w=c(0,1,0,1))
    X.dgs <- rmh(model=mod11,start=list(n.start=300),
                 control=list(nrep=10,nverb=5))
    
    # Diggle-Gratton:
    mod12 <- list(cif="diggra",
                  par=c(beta=1800,kappa=3,delta=0.02,rho=0.04),
                  w=square(1))
    X.diggra <- rmh(model=mod12,start=list(n.start=300),
                    control=list(nrep=10,nverb=5))
    
    # Geyer:
    mod13 <- list(cif="geyer",par=c(beta=1.25,gamma=1.6,r=0.2,sat=4.5),
                  w=c(0,10,0,10))
    X1.geyer <- rmh(model=mod13,start=list(n.start=200),
                    control=list(nrep=10,nverb=5))

    # Geyer; same as a Strauss process with parameters
    # (beta=2.25,gamma=0.16,r=0.7):

    mod14 <- list(cif="geyer",par=c(beta=2.25,gamma=0.4,r=0.7,sat=10000),
                  w=c(0,10,0,10))
    X2.geyer <- rmh(model=mod14,start=list(n.start=200),
                    control=list(nrep=10,nverb=5))

    mod15 <- list(cif="geyer",par=c(beta=8.1,gamma=2.2,r=0.08,sat=3))
    data(redwood)
    X3.geyer <- rmh(model=mod15,start=list(x.start=redwood),
                    control=list(periodic=TRUE,nrep=10,nverb=5))

    # Geyer, starting from the redwood data set, simulating
    # on a torus, and conditioning on n:
    X4.geyer <- rmh(model=mod15,start=list(x.start=redwood),
                    control=list(p=1,periodic=TRUE,nrep=10,nverb=5))
   



